summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/spinbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/spinbox.h')
-rw-r--r--kalarm/lib/spinbox.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kalarm/lib/spinbox.h b/kalarm/lib/spinbox.h
index 4b269d6a..081087db 100644
--- a/kalarm/lib/spinbox.h
+++ b/kalarm/lib/spinbox.h
@@ -45,18 +45,18 @@ class SpinBox : public TQSpinBox
TQ_OBJECT
public:
/** Constructor.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- explicit SpinBox(TQWidget* tqparent = 0, const char* name = 0);
+ explicit SpinBox(TQWidget* parent = 0, const char* name = 0);
/** Constructor.
* @param minValue The minimum value which the spin box can have.
* @param maxValue The maximum value which the spin box can have.
* @param step The (unshifted) step interval.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- SpinBox(int minValue, int maxValue, int step = 1, TQWidget* tqparent = 0, const char* name = 0);
+ SpinBox(int minValue, int maxValue, int step = 1, TQWidget* parent = 0, const char* name = 0);
/** Returns true if the widget is read only. */
bool isReadOnly() const { return mReadOnly; }
/** Sets whether the spin box can be changed by the user.
@@ -45,18 +45,18 @@ class SpinBox : public TQSpinBox
public:
/** Constructor.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/
@@ -45,18 +45,18 @@ class SpinBox : public TQSpinBox
* @param maxValue The maximum value which the spin box can have.
* @param step The (unshifted) step interval.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/